@@ -1,5 +1,3 @@
-import json
-
 from algora.api.service.backtest.state.model import PortfolioStateRequest, CashPaymentRequest
 from algora.common.enum import Order
 
@@ -25,12 +23,12 @@ def _get_all_cash_payments_request_info(backtest_id: str, order: Order, **kwargs
 def _create_portfolio_state_request_info(request: PortfolioStateRequest) -> dict:
     return {
         "endpoint": "config/backtest/state/portfolio",
-        "json": json.loads(request.json())
+        "json": request.request_dict()
     }
 
 
 def _create_cash_payment_request_info(request: CashPaymentRequest) -> dict:
     return {
         "endpoint": "config/backtest/state/cash_payment",
-        "json": json.loads(request.json())
+        "json": request.request_dict()
     }
