@@ -1,5 +1,3 @@
-import json
-
 from algora.api.service.datasets.field.model import FieldRequest
 
 
@@ -12,14 +10,14 @@ def _get_field_request_info(id: str) -> dict:
 def _create_field_request_info(request: FieldRequest) -> dict:
     return {
         "endpoint": "config/datasets/field",
-        "json": json.loads(request.json())
+        "json": request.request_dict()
     }
 
 
 def _update_field_request_info(id: str, request: FieldRequest):
     return {
         "endpoint": f"config/datasets/field/{id}",
-        "json": json.loads(request.json())
+        "json": request.request_dict()
     }
 
 
