@@ -5,20 +5,10 @@ import base64
 import json
 from abc import ABC
 from datetime import date, datetime, tzinfo
-from enum import Enum
 
 from pydantic import BaseModel, create_model
 
-from algora.common.function import date_to_timestamp, datetime_to_timestamp
-
-
-class BaseEnum(str, Enum):
-    """
-    Base enum class used by all enum classes.
-
-    Note: Inheriting from str is necessary to correctly serialize output of enum
-    """
-    pass
+from algora.common.date import date_to_timestamp, datetime_to_timestamp
 
 
 class Base(ABC, BaseModel):
@@ -49,28 +39,56 @@ class Base(ABC, BaseModel):
     @classmethod
     def new_fields(cls, *args, **kwargs):
         """
-        TODO DOCUMENT @will
+        The only fields that need to be returned are fields using the custom algora Annotation class or class that
+        contain the custom algora Annotation class
+
+        Cases:
+            - Annotated Field:
+                class Container:
+                    foo: AnnotatedClass.annotation()
+
+                    @classmethod
+                    def new_fields(cls):
+                        return {'foo': (AnnotatedClass.annotation(), None)}
+
+            - Internal field with a class type that contains an annotated field
+                class ContainerSquared(Base):
+                    container: Container
+
+                    @classmethod
+                    def new_fields(cls, updated_container_cls):
+                        return {'container': (updated_container_cls, None)}
 
         Args:
             *args:
             **kwargs:
 
         Returns:
-
+            A mapping of the updated fields and types
         """
         return {}
 
     @classmethod
     def update(cls, *args, **kwargs):
         """
-        TODO DOCUMENT @will
+        This method creates a new class instance that can be used for serialization
+
+        Note: the returned class must be used for serialization and object creation for you to see the updated effects
+
+        Example:
+            AnnotatedClass.add_types(Fizz)
+            c = Container.update()
+            c_squared = ContainerSquared.update(c)
+
+            container = c(foo=self.foo)
+            container_squared = c_squared(container=container)
 
         Args:
             *args:
             **kwargs:
 
         Returns:
-
+            The updated class
         """
         new_fields = cls.new_fields(*args, **kwargs)
         return create_model(cls.__name__, __base__=cls, **new_fields)
